@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 #--------------------------------------------------------------------------
 
@@ -88,12 +88,13 @@ sub search {
 	$self->found(0);
 	$self->book(undef);
 
-	my $url = SEARCH . sprintf(QUERY,$isbn);
 	my $mech = WWW::Mechanize->new();
     $mech->agent_alias( 'Linux Mozilla' );
-	$mech->get( $url );
+
+	my $url = SEARCH . sprintf(QUERY,$isbn);
+	eval { $mech->get( $url ) };
     return $self->handler("O'Reilly Media website appears to be unavailable.")
-	    unless($mech->success());
+	    unless($@ || $mech->success());
 
 	# The Search Results page
     my $content = $mech->content();
@@ -105,7 +106,10 @@ sub search {
 	    return $self->handler("Could not extract data from the O'Reilly Media search page [".($mech->uri())."].");
     }
 
-	$mech->get( $book );
+	eval { $mech->get( $book ) };
+    return $self->handler("O'Reilly Media website appears to be unavailable.")
+	    unless($@ || $mech->success());
+
     my $html = $mech->content();
     my $data = {};
 
@@ -158,7 +162,6 @@ Requires the following modules be installed:
 
 L<WWW::Scraper::ISBN::Driver>,
 L<WWW::Mechanize>,
-L<Template::Extract>
 
 =head1 SEE ALSO
 
@@ -166,6 +169,18 @@ L<WWW::Scraper::ISBN>,
 L<WWW::Scraper::ISBN::Record>,
 L<WWW::Scraper::ISBN::Driver>
 
+=head1 BUGS, PATCHES & FIXES
+
+There are no known bugs at the time of this release. However, if you spot a
+bug or are experiencing difficulties that are not explained within the POD
+documentation, please send an email to barbie@cpan.org or submit a bug to the
+RT system (http://rt.cpan.org/Public/Dist/Display.html?Name=WWW-Scraper-ISBN-ORA_Driver).
+However, it would help greatly if you are able to pinpoint problems or even
+supply a patch.
+
+Fixes are dependant upon their severity and my availablity. Should a fix not
+be forthcoming, please feel free to (politely) remind me.
+
 =head1 AUTHOR
 
   Barbie, <barbie@cpan.org>
